#!/usr/bin/env python
# encoding: utf-8
"""
ExcludeMouseData.py

Created by Szymon Łęski on 2013-01-21.
Copyright (c) 2013 Laboratory of Neuroinformatics. All rights reserved.
"""

import sys
import os
import time


class ExcludeMouseData(object):
    """
    A class for storing information about excluded data segments / modalities
    """
    def __init__(self, **kwargs):
        self.starttime = kwargs.pop('starttime', 0)
        self.endtime = kwargs.pop('endtime', 0)
        self.logtype = kwargs.pop('logtype', None) 
        # logtype should be one of: Lickometer, Presence, Corner, Cage, SocialBox, 
        # AnimalGate, ???
        self.notes = kwargs.pop('notes', None)
        
        # The rest of the fields goes to the location dictionary
        self.location = {}
        for key in ['cage', 'corner', 'side']:
            self.location[key] = kwargs.pop(key, None)
        for key in kwargs:
            self.location[key] = kwargs.pop(key, None)
            
    def __repr__(self):
        ss = '\n'.join(['Exclude %s from %s to %s' %(self.logtype, 
                        time.strftime('%d.%m %H:%M', 
                                time.localtime(self.starttime)), 
                        time.strftime('%d.%m %H:%M', 
                                time.localtime(self.endtime))),
                       'in location: %s.' %(', '.join([key + ' = ' + str(value)
                       for key, value in self.location.iteritems()]))])
        if self.notes is not None:
            ss = '\n'.join([ss, '', 'Notes:', self.notes])
        return ss